@@ -46,12 +46,23 @@ SUPPORTED_VALUES = {
     "nsem": [ "count", "time", "mass", "measure" ],
 };
 
+
+def getstrval(v):
+    if v is None:
+        return None
+    if hasattr(v, 'rule'):
+        return v.rule()
+    return str(v)
+
+
 def valence_rule(lemma="", pos=""):
-    return f"lemma={lemma},pos2={pos},node=concept|sit"
+    return f"lemma={lemma},pos2={getstrval(pos)},node=concept|sit"
+
 
 def root_rule():
     return "__root__"
 
+
 def rule(
     lemma=None,
     pos=None,
@@ -73,7 +84,7 @@ def rule(
 ):
     for key in SUPPORTED_VALUES:
         if key in locals():
-            val = locals()[key]
+            val = getstrval(locals()[key])
             if val is not None:
                 if SUPPORTED_VALUES[key] is not None:
                     if val not in SUPPORTED_VALUES[key]:
@@ -81,11 +92,12 @@ def rule(
     output = []
     for key in SUPPORTED_VALUES:
         if key in locals():
-            val = locals()[key]
+            val = getstrval(locals()[key])
             if val is not None:
                 output.append(f"{key}={val}")
     return ",".join(output)
 
+
 class gram():
     def __init__(self, value):
         self.value = value
@@ -140,6 +152,7 @@ def quant(gr, **kwargs):
         quant_conds.append(f"{key}={val_str}")
     return "QUANT[" + ",".join(quant_conds) + "] " + gr.rule()
 
+
 infp = gram('infp')
 np = gram('np')
 prepnp = gram('prepnp')
